@@ -201,6 +201,7 @@ gst_dialog_constructor (GType                  type,
 	GstDialog *dialog;
 	GstDialogPrivate *priv;
 	GtkWidget *toplevel;
+	GError *error = NULL;
 
 	object = (* G_OBJECT_CLASS (gst_dialog_parent_class)->constructor) (type,
 									    n_construct_properties,
@@ -211,8 +212,9 @@ gst_dialog_constructor (GType                  type,
 	if (priv->tool && priv->widget_name) {
 		priv->builder = gtk_builder_new ();
 
-		if (!gtk_builder_add_from_file (priv->builder, priv->tool->ui_path, NULL)) {
-			g_critical ("UI file not found: %s\n", priv->tool->ui_path);
+		if (!gtk_builder_add_from_file (priv->builder, priv->tool->ui_path, &error)) {
+			g_critical ("Error loading UI: %s", error->message);
+			g_error_free (error);
 
 			/* no point in continuing */
 			exit (-1);
@@ -648,6 +650,19 @@ gst_dialog_get_editing (GstDialog *dialog)
 	return (priv->edit_dialogs != NULL);
 }
 
+GtkWidget *
+gst_dialog_get_topmost_edit_dialog (GstDialog *dialog)
+{
+	GstDialogPrivate *priv;
+
+	priv = GST_DIALOG_GET_PRIVATE (dialog);
+
+	if (!priv->edit_dialogs)
+		return NULL;
+
+	return GTK_WIDGET (priv->edit_dialogs->data);
+}
+
 void
 gst_dialog_add_edit_dialog (GstDialog *dialog,
 			    GtkWidget *edit_dialog)
@@ -688,3 +703,16 @@ gst_dialog_stop_editing (GstDialog *dialog)
 	g_slist_free (priv->edit_dialogs);
 	priv->edit_dialogs = NULL;
 }
+
+void
+gst_dialog_authenticate (GstDialog *dialog)
+{
+#ifdef HAVE_POLKIT
+	GstDialogPrivate *priv;
+
+	if (!gst_dialog_is_authenticated (dialog)) {
+		priv = GST_DIALOG_GET_PRIVATE (dialog);
+		gtk_button_clicked (GTK_BUTTON (priv->polkit_button));
+	}
+#endif
+}
